@@ -96,7 +96,7 @@ KMO <- function(x, use = c("pairwise.complete.obs", "all.obs", "complete.obs",
   }
 
   # Check if correlation matrix is positive definite
-  if(any(eigen(R, symmetric = TRUE, only.values = TRUE)$values <= 0)){
+  if(any(eigen(R, symmetric = TRUE, only.values = TRUE)$values <= .Machine$double.eps^.6)){
 
     R <- psych::cor.smooth(R)
     R_i <- try(solve(R), silent = TRUE)
