@@ -74,39 +74,39 @@ test_that("output class and dimensions are correct", {
 
   expect_named(efa_cor, c("orig_R", "h2_init", "h2", "orig_eigen", "init_eigen",
                           "final_eigen", "iter", "convergence", "unrot_loadings",
-                          "vars_accounted", "fit_indices", "settings"))
+                          "vars_accounted", "fit_indices", "model_implied_R", "settings"))
   expect_named(efa_raw, c("orig_R", "h2_init", "h2", "orig_eigen", "init_eigen",
                           "final_eigen", "iter", "convergence", "unrot_loadings",
-                          "vars_accounted", "fit_indices", "settings"))
+                          "vars_accounted", "fit_indices", "model_implied_R", "settings"))
   expect_named(efa_psych, c("orig_R", "h2_init", "h2", "orig_eigen", "init_eigen",
                             "final_eigen", "iter", "convergence", "unrot_loadings",
-                            "vars_accounted", "fit_indices", "rot_loadings",
+                            "vars_accounted", "fit_indices", "model_implied_R", "rot_loadings",
                             "Phi", "Structure", "rotmat", "vars_accounted_rot",
                             "settings"))
   expect_named(efa_spss, c("orig_R", "h2_init", "h2", "orig_eigen", "init_eigen",
                            "final_eigen", "iter", "convergence", "unrot_loadings",
-                           "vars_accounted", "fit_indices", "rot_loadings",
+                           "vars_accounted", "fit_indices", "model_implied_R", "rot_loadings",
                            "Phi", "Structure", "rotmat", "vars_accounted_rot",
                            "settings"))
   expect_named(efa_ml, c("orig_R", "h2", "orig_eigen", "final_eigen", "iter",
                          "convergence", "unrot_loadings", "vars_accounted",
-                         "fit_indices", "settings"))
+                         "fit_indices", "model_implied_R", "settings"))
   expect_named(efa_uls, c("orig_R", "h2", "orig_eigen", "final_eigen", "iter",
                          "convergence", "unrot_loadings", "vars_accounted",
-                         "fit_indices", "settings"))
+                         "fit_indices", "model_implied_R", "settings"))
   expect_named(efa_equa, c("orig_R", "h2_init", "h2", "orig_eigen", "init_eigen",
                            "final_eigen", "iter", "convergence", "unrot_loadings",
-                           "vars_accounted", "fit_indices", "rot_loadings",
+                           "vars_accounted", "fit_indices", "model_implied_R", "rot_loadings",
                            "rotmat", "vars_accounted_rot",
                            "settings"))
   expect_named(efa_quart, c("orig_R", "h2_init", "h2", "orig_eigen", "init_eigen",
                             "final_eigen", "iter", "convergence", "unrot_loadings",
-                            "vars_accounted", "fit_indices", "rot_loadings",
+                            "vars_accounted", "fit_indices", "model_implied_R", "rot_loadings",
                             "Phi", "Structure", "rotmat", "vars_accounted_rot",
                             "settings"))
   expect_named(efa_none, c("orig_R", "h2_init", "h2", "orig_eigen", "init_eigen",
                            "final_eigen", "iter", "convergence", "unrot_loadings",
-                           "vars_accounted", "fit_indices", "rot_loadings",
+                           "vars_accounted", "fit_indices", "model_implied_R", "rot_loadings",
                            "Phi", "Structure", "rotmat", "vars_accounted_rot",
                            "settings"))
 })
